import matplotlib.pyplot as plt

from astropy.wcs import WCS
from astropy.io import fits
from astropy.utils.data import get_pkg_data_filename

filename = get_pkg_data_filename('galactic_center/gc_msx_e.fits')

hdu = fits.open(filename)[0]
wcs = WCS(hdu.header)

plt.figure(figsize=(9, 4.5))

for istyle, style in enumerate([{}, 'ggplot', 'seaborn']):

    plt.style.use(style)

    ax = plt.subplot(1, 3, istyle + 1, projection=wcs)
    ax.imshow(hdu.data, vmin=-2.e-5, vmax=2.e-4, origin='lower')

    if style == {}:
        ax.set_title('Default', size=11)
    else:
        ax.set_title("plt.style.use('{0}')".format(style), size=11)

    ax.set_xlabel('Galactic Longitude')

    if istyle  == 0:
        ax.coords[1].set_axislabel('Galactic Latitude')
    elif istyle == 1:
        ax.coords[1].set_ticklabel_visible(False)
    else:
        ax.coords[1].set_axislabel('Galactic Latitude')
        ax.coords[1].set_ticklabel_position('r')
        ax.coords[1].set_axislabel_position('r')